@@ -25,6 +25,8 @@ extensions = [
     'sphinx.ext.graphviz',
     'openstackdocstheme',
     'oslo_config.sphinxconfiggen',
+    'oslo_policy.sphinxext',
+    'oslo_policy.sphinxpolicygen',
 ]
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
@@ -45,6 +47,9 @@ bug_tag = ''
 config_generator_config_file = '../../etc/zun/zun-config-generator.conf'
 sample_config_basename = '_static/zun'
 
+policy_generator_config_file = '../../etc/zun/zun-policy-generator.conf'
+sample_policy_basename = '_static/zun'
+
 # General information about the project.
 project = u'zun'
 copyright = u'2013, OpenStack Foundation'
@@ -73,11 +78,23 @@ htmlhelp_basename = '%sdoc' % project
 # [howto/manual]).
 latex_documents = [
     ('index',
-     '%s.tex' % project,
-     u'%s Documentation' % project,
-     u'OpenStack Foundation', 'manual'),
+     'doc-%s.tex' % project,
+     u'Zun Documentation',
+     u'Zun development team', 'manual'),
 ]
 
+# Disable usage of xindy https://bugzilla.redhat.com/show_bug.cgi?id=1643664
+latex_use_xindy = False
+
+latex_domain_indices = False
+
+latex_elements = {
+    'makeindex': '',
+    'printindex': '',
+    'preamble': r'\setcounter{tocdepth}{3}',
+    'extraclassoptions': 'openany',
+}
+
 # Must set this variable to include year, month, day, hours, and minutes.
 html_last_updated_fmt = '%Y-%m-%d %H:%M'
 
