@@ -11,9 +11,9 @@
 # under the License.
 
 from collections import defaultdict
-from docker import errors
-import mock
+from unittest import mock
 
+from docker import errors
 from oslo_utils import units
 from oslo_utils import uuidutils
 
@@ -22,7 +22,6 @@ from zun.common import exception
 from zun import conf
 from zun.container.docker.driver import DockerDriver
 from zun.container.docker import utils as docker_utils
-from zun import objects
 from zun.objects.container import Container
 from zun.tests.unit.container import base
 from zun.tests.unit.db import utils
@@ -101,8 +100,7 @@ class TestDockerDriver(base.DriverTestCase):
     @mock.patch('zun.network.neutron.NeutronAPI.expose_ports')
     @mock.patch('zun.network.kuryr_network.KuryrNetwork'
                 '.connect_container_to_network')
-    @mock.patch('zun.network.kuryr_network.KuryrNetwork'
-                '.create_or_update_port')
+    @mock.patch('zun.network.neutron.NeutronAPI.create_or_update_port')
     @mock.patch('zun.common.utils.get_security_group_ids')
     @mock.patch('zun.objects.container.Container.save')
     def test_create_image_path_is_none_with_overlay2(
@@ -138,8 +136,7 @@ class TestDockerDriver(base.DriverTestCase):
                                               image, networks, volumes)
         host_config = {}
         host_config['mem_limit'] = '512M'
-        host_config['cpu_quota'] = 100000
-        host_config['cpu_period'] = 100000
+        host_config['cpu_shares'] = 1024
         host_config['restart_policy'] = {'Name': 'no', 'MaximumRetryCount': 0}
         host_config['runtime'] = 'runc'
         host_config['binds'] = {}
@@ -153,6 +150,7 @@ class TestDockerDriver(base.DriverTestCase):
             'name': '%sea8e2a25-2901-438d-8157-de7ffd68d051' %
                     consts.NAME_PREFIX,
             'command': ['fake_command'],
+            'entrypoint': ['fake_entrypoint'],
             'environment': {'key1': 'val1', 'key2': 'val2'},
             'working_dir': '/home/ubuntu',
             'labels': {'key1': 'val1', 'key2': 'val2'},
@@ -163,6 +161,7 @@ class TestDockerDriver(base.DriverTestCase):
             'volumes': [],
             'networking_config': {'Id': 'val1', 'key1': 'val2'},
             'mac_address': 'fake_mac',
+            'ports': [('80', 'tcp')],
         }
         self.mock_docker.create_container.assert_called_once_with(
             image['repo'] + ":" + image['tag'], **kwargs)
@@ -174,8 +173,7 @@ class TestDockerDriver(base.DriverTestCase):
     @mock.patch('zun.network.neutron.NeutronAPI.expose_ports')
     @mock.patch('zun.network.kuryr_network.KuryrNetwork'
                 '.connect_container_to_network')
-    @mock.patch('zun.network.kuryr_network.KuryrNetwork'
-                '.create_or_update_port')
+    @mock.patch('zun.network.neutron.NeutronAPI.create_or_update_port')
     @mock.patch('zun.common.utils.get_security_group_ids')
     @mock.patch('zun.objects.container.Container.save')
     def test_create_image_path_is_none_with_devicemapper(
@@ -212,8 +210,7 @@ class TestDockerDriver(base.DriverTestCase):
                                               image, networks, volumes)
         host_config = {}
         host_config['mem_limit'] = '512M'
-        host_config['cpu_quota'] = 100000
-        host_config['cpu_period'] = 100000
+        host_config['cpu_shares'] = 1024
         host_config['restart_policy'] = {'Name': 'no', 'MaximumRetryCount': 0}
         host_config['runtime'] = 'runc'
         host_config['binds'] = {}
@@ -227,6 +224,7 @@ class TestDockerDriver(base.DriverTestCase):
             'name': '%sea8e2a25-2901-438d-8157-de7ffd68d051' %
                     consts.NAME_PREFIX,
             'command': ['fake_command'],
+            'entrypoint': ['fake_entrypoint'],
             'environment': {'key1': 'val1', 'key2': 'val2'},
             'working_dir': '/home/ubuntu',
             'labels': {'key1': 'val1', 'key2': 'val2'},
@@ -237,6 +235,7 @@ class TestDockerDriver(base.DriverTestCase):
             'volumes': [],
             'networking_config': {'Id': 'val1', 'key1': 'val2'},
             'mac_address': 'fake_mac',
+            'ports': [('80', 'tcp')],
         }
         self.mock_docker.create_container.assert_called_once_with(
             image['repo'] + ":" + image['tag'], **kwargs)
@@ -248,8 +247,7 @@ class TestDockerDriver(base.DriverTestCase):
     @mock.patch('zun.network.neutron.NeutronAPI.expose_ports')
     @mock.patch('zun.network.kuryr_network.KuryrNetwork'
                 '.connect_container_to_network')
-    @mock.patch('zun.network.kuryr_network.KuryrNetwork'
-                '.create_or_update_port')
+    @mock.patch('zun.network.neutron.NeutronAPI.create_or_update_port')
     @mock.patch('zun.common.utils.get_security_group_ids')
     @mock.patch('zun.objects.container.Container.save')
     def test_create_docker_api_version_1_24(
@@ -284,8 +282,7 @@ class TestDockerDriver(base.DriverTestCase):
                                               image, networks, volumes)
         host_config = {}
         host_config['mem_limit'] = '512M'
-        host_config['cpu_quota'] = 100000
-        host_config['cpu_period'] = 100000
+        host_config['cpu_shares'] = 1024
         host_config['restart_policy'] = {'Name': 'no', 'MaximumRetryCount': 0}
         host_config['runtime'] = None
         host_config['binds'] = {}
@@ -299,6 +296,7 @@ class TestDockerDriver(base.DriverTestCase):
             'name': '%sea8e2a25-2901-438d-8157-de7ffd68d051' %
                     consts.NAME_PREFIX,
             'command': ['fake_command'],
+            'entrypoint': ['fake_entrypoint'],
             'environment': {'key1': 'val1', 'key2': 'val2'},
             'working_dir': '/home/ubuntu',
             'labels': {'key1': 'val1', 'key2': 'val2'},
@@ -309,6 +307,7 @@ class TestDockerDriver(base.DriverTestCase):
             'volumes': [],
             'networking_config': {'Id': 'val1', 'key1': 'val2'},
             'mac_address': 'fake_mac',
+            'ports': [('80', 'tcp')],
         }
         self.mock_docker.create_container.assert_called_once_with(
             image['repo'] + ":" + image['tag'], **kwargs)
@@ -318,8 +317,7 @@ class TestDockerDriver(base.DriverTestCase):
 
     @mock.patch('zun.network.kuryr_network.KuryrNetwork'
                 '.connect_container_to_network')
-    @mock.patch('zun.network.kuryr_network.KuryrNetwork'
-                '.create_or_update_port')
+    @mock.patch('zun.network.neutron.NeutronAPI.create_or_update_port')
     @mock.patch('zun.common.utils.get_security_group_ids')
     @mock.patch('zun.objects.container.Container.save')
     def test_create_docker_api_version_1_24_runtime_not_supported(
@@ -553,7 +551,7 @@ class TestDockerDriver(base.DriverTestCase):
         self.mock_docker.inspect_container = mock.Mock(
             return_value={'State': 'created',
                           'Config': {'Cmd': ['fake_command']}})
-        mock_container = mock.MagicMock()
+        mock_container = mock.MagicMock(task_state=None)
         mock_container.status = consts.CREATING
         self.driver.show(self.context, mock_container)
         self.mock_docker.inspect_container.assert_called_once_with(
@@ -598,8 +596,8 @@ class TestDockerDriver(base.DriverTestCase):
                 'FinishedAt': '0001-01-01T00:00:00Z',
             }}
         )
-        mock_container = mock.MagicMock()
-        mock_container.status = 'existed'
+        mock_container = mock.MagicMock(task_state=None)
+        mock_container.status = 'Created'
         mock_container.Error = 'Container start error.'
         self.driver.show(self.context, mock_container)
         self.mock_docker.inspect_container.assert_called_once_with(
@@ -615,8 +613,8 @@ class TestDockerDriver(base.DriverTestCase):
                 'FinishedAt': '0001-01-01T00:00:00Z',
             }}
         )
-        mock_container = mock.MagicMock()
-        mock_container.status = 'UNKNOWN'
+        mock_container = mock.MagicMock(task_state=None)
+        mock_container.status = 'Running'
         mock_container.Error = 'Container run error.'
         self.driver.show(self.context, mock_container)
         self.mock_docker.inspect_container.assert_called_once_with(
@@ -751,15 +749,6 @@ class TestDockerDriver(base.DriverTestCase):
         self.mock_docker.commit.assert_called_once_with(
             mock_container.container_id, "repo", "tag")
 
-    def test_get_container_name(self):
-        mock_container = mock.MagicMock(
-            uuid='ea8e2a25-2901-438d-8157-de7ffd68d051')
-        result_container_name = self.driver.get_container_name(
-            mock_container)
-        self.assertEqual(
-            result_container_name,
-            '%sea8e2a25-2901-438d-8157-de7ffd68d051' % consts.NAME_PREFIX)
-
     def test_execute_resize(self):
         self.mock_docker.exec_resize = mock.Mock()
         fake_exec_id = 'fake_id'
@@ -795,17 +784,6 @@ class TestDockerDriver(base.DriverTestCase):
         self.assertEqual({"dev.type": "product"}, host_info['labels'])
         self.assertEqual('fake-dir', host_info['docker_root_dir'])
 
-    def test_get_cpu_used(self):
-        self.mock_docker.containers = mock.Mock()
-        self.mock_docker.containers.return_value = [{'Id': '123456'}]
-        self.mock_docker.inspect_container = mock.Mock()
-        self.mock_docker.inspect_container.return_value = {
-            'HostConfig': {'NanoCpus': 1.0 * 1e9,
-                           'CpuPeriod': 0,
-                           'CpuQuota': 0}}
-        cpu_used = self.driver.get_cpu_used()
-        self.assertEqual(1.0, cpu_used)
-
     def test_stats(self):
         self.mock_docker.stats = mock.Mock()
         mock_container = mock.MagicMock()
@@ -913,12 +891,11 @@ class TestDockerDriver(base.DriverTestCase):
                 '.LinuxHost.get_cpu_numa_info')
     @mock.patch('zun.container.docker.driver.DockerDriver'
                 '.get_total_disk_for_container')
-    @mock.patch('zun.container.driver.ContainerDriver.get_host_mem')
+    @mock.patch('zun.container.docker.driver.DockerDriver'
+                '.get_host_mem')
     @mock.patch(
         'zun.container.docker.driver.DockerDriver.get_host_info')
-    @mock.patch(
-        'zun.container.docker.driver.DockerDriver.get_cpu_used')
-    def test_get_available_resources(self, mock_cpu_used, mock_info, mock_mem,
+    def test_get_available_resources(self, mock_info, mock_mem,
                                      mock_disk, mock_numa_cpu, mock_numa_mem,
                                      mock_output):
         self.driver = DockerDriver()
@@ -943,24 +920,21 @@ class TestDockerDriver(base.DriverTestCase):
                                   'runtimes': ['runc'],
                                   'enable_cpu_pinning': False,
                                   'docker_root_dir': '/var/lib/docker'}
-        mock_cpu_used.return_value = 1.0
-        mock_disk.return_value = 80
-        node_obj = objects.ComputeNode()
-        self.driver.get_available_resources(node_obj)
-        self.assertEqual(_numa_topo_spec, node_obj.numa_topology.to_list())
-        self.assertEqual(node_obj.mem_total, 100)
-        self.assertEqual(node_obj.mem_free, 50)
-        self.assertEqual(node_obj.mem_available, 50)
-        self.assertEqual(10, node_obj.total_containers)
-        self.assertEqual(8, node_obj.running_containers)
-        self.assertEqual(0, node_obj.paused_containers)
-        self.assertEqual(2, node_obj.stopped_containers)
-        self.assertEqual(48, node_obj.cpus)
-        self.assertEqual(1.0, node_obj.cpu_used)
-        self.assertEqual('x86_64', node_obj.architecture)
-        self.assertEqual('linux', node_obj.os_type)
-        self.assertEqual('CentOS', node_obj.os)
-        self.assertEqual('3.10.0-123', node_obj.kernel_version)
-        self.assertEqual({'dev.type': 'product'}, node_obj.labels)
-        self.assertEqual(80, node_obj.disk_total)
-        self.assertEqual(['runc'], node_obj.runtimes)
+        mock_disk.return_value = (100, 20)
+        data = self.driver.get_available_resources()
+        self.assertEqual(_numa_topo_spec, data['numa_topology'].to_list())
+        self.assertEqual(100, data['mem_total'])
+        self.assertEqual(50, data['mem_free'], 50)
+        self.assertEqual(50, data['mem_available'])
+        self.assertEqual(10, data['total_containers'])
+        self.assertEqual(8, data['running_containers'])
+        self.assertEqual(0, data['paused_containers'])
+        self.assertEqual(2, data['stopped_containers'])
+        self.assertEqual(48, data['cpus'])
+        self.assertEqual('x86_64', data['architecture'])
+        self.assertEqual('linux', data['os_type'])
+        self.assertEqual('CentOS', data['os'])
+        self.assertEqual('3.10.0-123', data['kernel_version'])
+        self.assertEqual({'dev.type': 'product'}, data['labels'])
+        self.assertEqual(80, data['disk_total'])
+        self.assertEqual(['runc'], data['runtimes'])
