@@ -13,13 +13,14 @@
 Tests For kuryr network
 """
 import copy
-import mock
+from unittest import mock
 
 from neutronclient.common import exceptions as n_exc
 
 from zun.common import exception
 from zun.network import kuryr_network
 from zun.objects.container import Container
+from zun.objects.zun_network import ZunNetwork
 from zun.tests import base
 from zun.tests.unit.db import utils
 
@@ -68,7 +69,7 @@ class FakeNeutronClient(object):
         self.ports.append(port_data)
         return port
 
-    def update_port(self, port_id, port):
+    def update_port(self, port_id, port, **kwargs):
         port_data = copy.deepcopy(port['port'])
         for port in self.ports:
             if port['id'] == port_id:
@@ -82,6 +83,47 @@ class FakeNeutronClient(object):
                     ports.remove(port)
         return {'ports': copy.deepcopy(ports)}
 
+    def create_or_update_port(self, container, network_uuid,
+                              requested_network, device_owner,
+                              security_groups=None, **kwargs):
+        if requested_network.get('port'):
+            neutron_port_id = requested_network.get('port')
+            neutron_port = self.get_neutron_port(neutron_port_id)
+            # update device_id in port
+            port_req_body = {'port': {'device_id': container.uuid}}
+            self.update_port(neutron_port_id, port_req_body)
+        else:
+            port_dict = {
+                'network_id': network_uuid,
+                'tenant_id': self.context.project_id,
+                'device_id': container.uuid,
+            }
+            ip_addr = requested_network.get("fixed_ip")
+            if ip_addr:
+                port_dict['fixed_ips'] = [{'ip_address': ip_addr}]
+            neutron_port = self.create_port({'port': port_dict})
+            neutron_port = neutron_port['port']
+
+        addresses = []
+        for fixed_ip in neutron_port['fixed_ips']:
+            addresses.append({
+                'addr': fixed_ip['ip_address'],
+                'version': 4,
+                'port': neutron_port['id'],
+                'subnet_id': fixed_ip['subnet_id'],
+                'preserve_on_delete': requested_network['preserve_on_delete'],
+            })
+
+        return addresses, neutron_port
+
+    def delete_or_unbind_ports(self, ports, ports_to_delete):
+        for port_id in ports:
+            if port_id in ports_to_delete:
+                self.delete_port(port_id)
+            else:
+                port_req_body = {'port': {'device_id': ''}}
+                self.update_port(port_id, port_req_body)
+
     def delete_port(self, port_id):
         for port in self.ports:
             if port['id'] == port_id:
@@ -142,19 +184,20 @@ class KuryrNetworkTestCase(base.TestCase):
         self.network_api.init(self.context, self.docker_api)
         self.network_api.neutron_api = FakeNeutronClient()
 
+    @mock.patch.object(ZunNetwork, 'create')
+    @mock.patch.object(ZunNetwork, 'save')
     @mock.patch('zun.network.neutron.NeutronAPI')
-    def test_create_network_without_subnetpool(self,
-                                               mock_neutron_api_cls):
+    def test_create_network_without_subnetpool(
+            self, mock_neutron_api_cls, mock_save, mock_create):
         self.network_api.neutron_api.subnets[0].pop('subnetpool_id')
         mock_neutron_api_cls.return_value = self.network_api.neutron_api
         name = 'test_kuryr_network'
         neutron_net_id = 'fake-net-id'
         with mock.patch.object(self.network_api.docker, 'create_network',
-                               return_value='docker-net'
+                               return_value={'Id': 'docker-net'}
                                ) as mock_create_network:
-            docker_network = self.network_api.create_network(name,
-                                                             neutron_net_id)
-        self.assertEqual('docker-net', docker_network)
+            network = self.network_api.create_network(name, neutron_net_id)
+        self.assertEqual('docker-net', network.network_id)
         mock_create_network.assert_called_once_with(
             name=name,
             driver='kuryr',
@@ -162,25 +205,24 @@ class KuryrNetworkTestCase(base.TestCase):
             ipam={'Config': [{'Subnet': '10.5.0.0/16', 'Gateway': '10.5.0.1'}],
                   'Driver': 'kuryr',
                   'Options': {'neutron.net.shared': 'False',
-                              'neutron.subnet.uuid': 'fake-subnet-id',
-                              'neutron.pool.uuid': None}},
+                              'neutron.subnet.uuid': 'fake-subnet-id'}},
             options={'neutron.net.uuid': 'fake-net-id',
                      'neutron.net.shared': 'False',
-                     'neutron.subnet.uuid': 'fake-subnet-id',
-                     'neutron.pool.uuid': None})
+                     'neutron.subnet.uuid': 'fake-subnet-id'})
 
+    @mock.patch.object(ZunNetwork, 'create')
+    @mock.patch.object(ZunNetwork, 'save')
     @mock.patch('zun.network.neutron.NeutronAPI')
-    def test_create_network_with_subnetpool(self,
-                                            mock_neutron_api_cls):
+    def test_create_network_with_subnetpool(
+            self, mock_neutron_api_cls, mock_save, mock_create):
         mock_neutron_api_cls.return_value = self.network_api.neutron_api
         name = 'test_kuryr_network'
         neutron_net_id = 'fake-net-id'
         with mock.patch.object(self.network_api.docker, 'create_network',
-                               return_value='docker-net'
+                               return_value={'Id': 'docker-net'}
                                ) as mock_create_network:
-            docker_network = self.network_api.create_network(name,
-                                                             neutron_net_id)
-        self.assertEqual('docker-net', docker_network)
+            network = self.network_api.create_network(name, neutron_net_id)
+        self.assertEqual('docker-net', network.network_id)
         mock_create_network.assert_called_once_with(
             name=name,
             driver='kuryr',
@@ -188,16 +230,39 @@ class KuryrNetworkTestCase(base.TestCase):
             ipam={'Config': [{'Subnet': '10.5.0.0/16', 'Gateway': '10.5.0.1'}],
                   'Driver': 'kuryr',
                   'Options': {'neutron.net.shared': 'False',
-                              'neutron.subnet.uuid': 'fake-subnet-id',
-                              'neutron.pool.uuid': 'fake-subnetpool-id'}},
+                              'neutron.subnet.uuid': 'fake-subnet-id'}},
             options={'neutron.net.uuid': 'fake-net-id',
                      'neutron.net.shared': 'False',
-                     'neutron.subnet.uuid': 'fake-subnet-id',
-                     'neutron.pool.uuid': 'fake-subnetpool-id'})
+                     'neutron.subnet.uuid': 'fake-subnet-id'})
+
+    @mock.patch.object(ZunNetwork, 'create')
+    @mock.patch.object(ZunNetwork, 'save')
+    @mock.patch.object(ZunNetwork, 'list')
+    @mock.patch('zun.network.neutron.NeutronAPI')
+    def test_create_network_already_exist(
+            self, mock_neutron_api_cls, mock_list, mock_save, mock_create):
+        mock_neutron_api_cls.return_value = self.network_api.neutron_api
+        name = 'test_kuryr_network'
+        neutron_net_id = 'fake-net-id'
+        docker_net_id = 'docker-net'
+        fake_network = mock.Mock()
+        fake_network.network_id = docker_net_id
+        mock_list.return_value = [fake_network]
+        mock_create.side_effect = exception.NetworkAlreadyExists(
+            field='neutron_net_id', value=neutron_net_id)
+        with mock.patch.object(self.network_api.docker, 'networks',
+                               return_value=[{'Id': docker_net_id}]
+                               ) as mock_list_network:
+            network = self.network_api.create_network(name, neutron_net_id)
+        self.assertEqual(docker_net_id, network.network_id)
+        mock_list.assert_called_once_with(
+            self.context, filters={'neutron_net_id': neutron_net_id})
+        mock_list_network.assert_called_once_with(names=[name])
 
     def test_remove_network(self):
-        network_name = 'c02afe4e-8350-4263-8078'
-        self.network_api.remove_network(network_name)
+        network = mock.Mock(name='c02afe4e-8350-4263-8078')
+        self.network_api.remove_network(network)
+        network.destroy.assert_called_once_with()
 
     def test_inspect_network(self):
         network_name = 'c02afe4e-8350-4263-8078'
@@ -315,4 +380,5 @@ class KuryrNetworkTestCase(base.TestCase):
 
         mock_update_port.assert_called_once_with(
             'fake-port-id',
-            {'port': {'security_groups': ['sg1', 'sg2']}})
+            {'port': {'security_groups': ['sg1', 'sg2']}},
+            admin=True)
